pub struct RegisterThree(pub u8);Tuple Fields
0: u8Implementations
Sourceimpl RegisterThree
impl RegisterThree
Sourcepub fn hi_z(&self) -> bool
pub fn hi_z(&self) -> bool
This bit sets the output driver into a true high-impedance state. The device must be enabled to go into the high-impedance state. When in hardware shutdown or standby mode, the output drivers have 15 kΩ to ground. When the HI_Z bit is asserted, the hi-Z functionality takes effect immediately, even if a transaction is taking place.
Sourcepub fn library_selection(&self) -> LibrarySelection
pub fn library_selection(&self) -> LibrarySelection
Waveform library selection value. This bit determines which library the playback engine selects when the GO bit is set.
Sourcepub fn set_hi_z(&mut self, value: bool)
pub fn set_hi_z(&mut self, value: bool)
This bit sets the output driver into a true high-impedance state. The device must be enabled to go into the high-impedance state. When in hardware shutdown or standby mode, the output drivers have 15 kΩ to ground. When the HI_Z bit is asserted, the hi-Z functionality takes effect immediately, even if a transaction is taking place.
Sourcepub fn set_library_selection(&mut self, value: u8)
pub fn set_library_selection(&mut self, value: u8)
Waveform library selection value. This bit determines which library the playback engine selects when the GO bit is set.